"""Store and retrieve Google Calendar events."""

from __future__ import annotations


class Event:
    """A class to represent an event on a Google Calendar."""


def get() -> list[Event]:
    """Return all events."""


def search() -> list[Event]:
    """Return all events matching search criteria."""


def create(event: Event) -> None:
    """Add event to Google Calendar."""


def delete(event: Event) -> None:
    """Remove event from Google Calendar."""



"""Store and retrieve Google Account information."""

from __future__ import annotations


class Account:
    """A class to represent a Google Account."""


def get() -> list[Account]:
    """Return accounts that have been registered."""


def register(account: Account) -> None:
    """Add account to the set of known accounts."""


def remove(account: Account) -> None:
    """Remove account from the set of known accounts."""



"""Store and retrieve Google Calendar information."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from gcal_manager.account import Account


class Calendar:
    """A class to represent a Google Calendar."""


def get(account: Account) -> list[Calendar]:
    """Return all calendars associated with an account."""


def remove(calendar: Calendar) -> None:
    """Remove calendar from the set of known calendars."""



"""Store and retrieve task templates."""

from __future__ import annotations


class Task:
    """A class to represent a task template."""


def get() -> list[Task]:
    """Return all task templates."""


def search() -> list[Task]:
    """Return all task templates matching search criteria."""


def create(task: Task) -> None:
    """Add task template to available templates."""


def delete(task: Task) -> None:
    """Remove task template for available templates."""



"""Store and retrieve contexts."""

from __future__ import annotations


class Context:
    """A class to represent a context."""


def get(context: str | None = None) -> list[Context]:
    """Return contexts."""


def register(context: Context) -> None:
    """Add context to the set of known contexts."""


def remove(context: Context) -> None:
    """Remove context from the set of known contexts."""
